# crypto_apis

CryptoApis - the Ruby gem for the CryptoAPIs

Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- Package version: 1.2.1
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://cryptoapis.io](https://cryptoapis.io)

## Installation

```shell
gem install crypto_apis
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'crypto_apis'

# Setup authorization
CryptoApis.configure do |config|
  # Configure API key authorization: ApiKey
  config.api_key['ApiKey'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  # config.api_key_prefix['ApiKey'] = 'Bearer'
end

api_instance = CryptoApis::AssetsApi.new
opts = {
  context: 'context_example', # String | In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.
  asset_type: 'fiat', # String | Defines the type of the supported asset. This could be either \"crypto\" or \"fiat\".
  crypto_type: 'coin', # String | Subtype of the crypto assets. Could be COIN or TOKEN
  limit: 50, # Integer | Defines how many items should be returned in the response per page basis.
  offset: 10, # Integer | The starting index of the response items, i.e. where the response should start listing the returned items.
  waas_enabled: true # Boolean | Show only if WaaS is/not enabled
}

begin
  #List Assets Details
  result = api_instance.list_assets_details(opts)
  p result
rescue CryptoApis::ApiError => e
  puts "Exception when calling AssetsApi->list_assets_details: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://rest.cryptoapis.io/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CryptoApis::AssetsApi* | [**list_assets_details**](docs/AssetsApi.md#list_assets_details) | **GET** /market-data/assets/details | List Assets Details
*CryptoApis::AutomaticCoinsForwardingApi* | [**create_automatic_coins_forwarding**](docs/AutomaticCoinsForwardingApi.md#create_automatic_coins_forwarding) | **POST** /blockchain-automations/{blockchain}/{network}/coins-forwarding/automations | Create Automatic Coins Forwarding
*CryptoApis::AutomaticCoinsForwardingApi* | [**delete_automatic_coins_forwarding**](docs/AutomaticCoinsForwardingApi.md#delete_automatic_coins_forwarding) | **DELETE** /blockchain-automations/{blockchain}/{network}/coins-forwarding/automations/{referenceId} | Delete Automatic Coins Forwarding
*CryptoApis::AutomaticCoinsForwardingApi* | [**list_coins_forwarding_automations**](docs/AutomaticCoinsForwardingApi.md#list_coins_forwarding_automations) | **GET** /blockchain-automations/{blockchain}/{network}/coins-forwarding/automations | List Coins Forwarding Automations
*CryptoApis::AutomaticTokensForwardingApi* | [**add_tokens_to_existing_from_address**](docs/AutomaticTokensForwardingApi.md#add_tokens_to_existing_from_address) | **POST** /blockchain-automations/{blockchain}/{network}/tokens-forwarding/automations/add-token | Add Tokens To Existing fromAddress
*CryptoApis::AutomaticTokensForwardingApi* | [**create_automatic_tokens_forwarding**](docs/AutomaticTokensForwardingApi.md#create_automatic_tokens_forwarding) | **POST** /blockchain-automations/{blockchain}/{network}/tokens-forwarding/automations | Create Automatic Tokens Forwarding
*CryptoApis::AutomaticTokensForwardingApi* | [**delete_automatic_tokens_forwarding**](docs/AutomaticTokensForwardingApi.md#delete_automatic_tokens_forwarding) | **DELETE** /blockchain-automations/{blockchain}/{network}/tokens-forwarding/automations/{referenceId} | Delete Automatic Tokens Forwarding
*CryptoApis::AutomaticTokensForwardingApi* | [**get_fee_address_details**](docs/AutomaticTokensForwardingApi.md#get_fee_address_details) | **GET** /blockchain-automations/{blockchain}/{network}/tokens-forwarding/fee-addresses | Get Fee Address Details
*CryptoApis::AutomaticTokensForwardingApi* | [**list_tokens_forwarding_automations**](docs/AutomaticTokensForwardingApi.md#list_tokens_forwarding_automations) | **GET** /blockchain-automations/{blockchain}/{network}/tokens-forwarding/automations | List Tokens Forwarding Automations
*CryptoApis::CreateSubscriptionsForApi* | [**mined_transaction**](docs/CreateSubscriptionsForApi.md#mined_transaction) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/transaction-mined | Mined transaction
*CryptoApis::CreateSubscriptionsForApi* | [**new_block**](docs/CreateSubscriptionsForApi.md#new_block) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/block-mined | New Block
*CryptoApis::CreateSubscriptionsForApi* | [**new_confirmed_coins_transactions**](docs/CreateSubscriptionsForApi.md#new_confirmed_coins_transactions) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-coins-transactions-confirmed | New confirmed coins transactions
*CryptoApis::CreateSubscriptionsForApi* | [**new_confirmed_coins_transactions_and_each_confirmation**](docs/CreateSubscriptionsForApi.md#new_confirmed_coins_transactions_and_each_confirmation) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-coins-transactions-confirmed-each-confirmation | New confirmed coins transactions and each confirmation
*CryptoApis::CreateSubscriptionsForApi* | [**new_confirmed_internal_transactions**](docs/CreateSubscriptionsForApi.md#new_confirmed_internal_transactions) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-internal-transactions-confirmed | New confirmed internal transactions
*CryptoApis::CreateSubscriptionsForApi* | [**new_confirmed_internal_transactions_and_each_confirmation**](docs/CreateSubscriptionsForApi.md#new_confirmed_internal_transactions_and_each_confirmation) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-internal-transactions-confirmed-each-confirmation | New confirmed internal transactions and each confirmation
*CryptoApis::CreateSubscriptionsForApi* | [**new_confirmed_tokens_transactions**](docs/CreateSubscriptionsForApi.md#new_confirmed_tokens_transactions) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-tokens-transactions-confirmed | New confirmed tokens transactions
*CryptoApis::CreateSubscriptionsForApi* | [**new_confirmed_tokens_transactions_and_each_confirmation**](docs/CreateSubscriptionsForApi.md#new_confirmed_tokens_transactions_and_each_confirmation) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-tokens-transactions-confirmed-each-confirmation | New confirmed tokens transactions and each confirmation
*CryptoApis::CreateSubscriptionsForApi* | [**new_unconfirmed_coins_transactions**](docs/CreateSubscriptionsForApi.md#new_unconfirmed_coins_transactions) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-coins-transactions-unconfirmed | New unconfirmed coins transactions
*CryptoApis::CreateSubscriptionsForApi* | [**new_unconfirmed_tokens_transactions**](docs/CreateSubscriptionsForApi.md#new_unconfirmed_tokens_transactions) | **POST** /blockchain-events/{blockchain}/{network}/subscriptions/address-tokens-transactions-unconfirmed | New unconfirmed tokens transactions
*CryptoApis::ExchangeRatesApi* | [**get_exchange_rate_by_asset_symbols**](docs/ExchangeRatesApi.md#get_exchange_rate_by_asset_symbols) | **GET** /market-data/exchange-rates/by-symbols/{fromAssetSymbol}/{toAssetSymbol} | Get Exchange Rate By Asset Symbols
*CryptoApis::ExchangeRatesApi* | [**get_exchange_rate_by_assets_ids**](docs/ExchangeRatesApi.md#get_exchange_rate_by_assets_ids) | **GET** /market-data/exchange-rates/by-asset-ids/{fromAssetId}/{toAssetId} | Get Exchange Rate By Assets IDs
*CryptoApis::FeaturesApi* | [**broadcast_locally_signed_transaction**](docs/FeaturesApi.md#broadcast_locally_signed_transaction) | **POST** /blockchain-tools/{blockchain}/{network}/transactions/broadcast | Broadcast Locally Signed Transaction
*CryptoApis::FeaturesApi* | [**validate_address**](docs/FeaturesApi.md#validate_address) | **POST** /blockchain-tools/{blockchain}/{network}/addresses/validate | Validate Address
*CryptoApis::GeneratingApi* | [**generate_deposit_address**](docs/GeneratingApi.md#generate_deposit_address) | **POST** /wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses | Generate Deposit Address
*CryptoApis::InformativeApi* | [**get_wallet_asset_details**](docs/InformativeApi.md#get_wallet_asset_details) | **GET** /wallet-as-a-service/wallets/{walletId}/{blockchain}/{network} | Get Wallet Asset Details
*CryptoApis::InformativeApi* | [**list_deposit_addresses**](docs/InformativeApi.md#list_deposit_addresses) | **GET** /wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses | List Deposit Addresses
*CryptoApis::InformativeApi* | [**list_supported_tokens**](docs/InformativeApi.md#list_supported_tokens) | **GET** /wallet-as-a-service/info/{blockchain}/{network}/supported-tokens | List Supported Tokens
*CryptoApis::InternalApi* | [**get_internal_transaction_by_transaction_hash_and_operation_id**](docs/InternalApi.md#get_internal_transaction_by_transaction_hash_and_operation_id) | **GET** /blockchain-data/{blockchain}/{network}/transactions/{transactionHash}/internal/{operationId} | Get Internal Transaction by Transaction Hash and Operation Id
*CryptoApis::InternalApi* | [**list_internal_transaction_details_by_transaction_hash**](docs/InternalApi.md#list_internal_transaction_details_by_transaction_hash) | **GET** /blockchain-data/{blockchain}/{network}/transactions/{transactionHash}/internal | List Internal Transaction Details by Transaction Hash
*CryptoApis::ManageSubscriptionsApi* | [**delete_blockchain_event_subscription**](docs/ManageSubscriptionsApi.md#delete_blockchain_event_subscription) | **DELETE** /blockchain-events/{blockchain}/{network}/subscriptions/{referenceId} | Delete Blockchain Event Subscription
*CryptoApis::ManageSubscriptionsApi* | [**list_blockchain_events_subscriptions**](docs/ManageSubscriptionsApi.md#list_blockchain_events_subscriptions) | **GET** /blockchain-events/{blockchain}/{network}/subscriptions | List Blockchain Events Subscriptions
*CryptoApis::MetadataApi* | [**list_supported_assets**](docs/MetadataApi.md#list_supported_assets) | **GET** /market-data/assets/supported | List Supported Assets
*CryptoApis::OmniLayerApi* | [**get_omni_transaction_details_by_transaction_id__txid**](docs/OmniLayerApi.md#get_omni_transaction_details_by_transaction_id__txid) | **GET** /blockchain-data/{blockchain}/{network}/omni/transactions/{transactionId} | Get Omni Transaction Details By Transaction ID (Txid)
*CryptoApis::OmniLayerApi* | [**get_unconfirmed_omni_transaction_by_transaction_id__txid**](docs/OmniLayerApi.md#get_unconfirmed_omni_transaction_by_transaction_id__txid) | **GET** /blockchain-data/{blockchain}/{network}/omni/transactions-unconfirmed/{transactionId} | Get Unconfirmed Omni Transaction By Transaction ID (Txid)
*CryptoApis::OmniLayerApi* | [**list_omni_tokens_by_address**](docs/OmniLayerApi.md#list_omni_tokens_by_address) | **GET** /blockchain-data/{blockchain}/{network}/omni/addresses/{address} | List Omni Tokens By Address
*CryptoApis::OmniLayerApi* | [**list_omni_transactions_by_address**](docs/OmniLayerApi.md#list_omni_transactions_by_address) | **GET** /blockchain-data/{blockchain}/{network}/omni/addresses/{address}/transactions | List Omni Transactions By Address
*CryptoApis::OmniLayerApi* | [**list_omni_transactions_by_block_hash**](docs/OmniLayerApi.md#list_omni_transactions_by_block_hash) | **GET** /blockchain-data/{blockchain}/{network}/omni/blocks/hash/{blockHash}/transactions | List Omni Transactions By Block Hash
*CryptoApis::OmniLayerApi* | [**list_omni_transactions_by_block_height**](docs/OmniLayerApi.md#list_omni_transactions_by_block_height) | **GET** /blockchain-data/{blockchain}/{network}/omni/blocks/height/{blockHeight}/transactions | List Omni Transactions By Block Height
*CryptoApis::OmniLayerApi* | [**list_unconfirmed_omni_transactions_by_address**](docs/OmniLayerApi.md#list_unconfirmed_omni_transactions_by_address) | **GET** /blockchain-data/{blockchain}/{network}/omni/address-transactions-unconfirmed/{address} | List Unconfirmed Omni Transactions By Address
*CryptoApis::OmniLayerApi* | [**list_unconfirmed_omni_transactions_by_property_id**](docs/OmniLayerApi.md#list_unconfirmed_omni_transactions_by_property_id) | **GET** /blockchain-data/{blockchain}/{network}/omni/properties/{propertyId}/transactions | List Unconfirmed Omni Transactions By Property ID
*CryptoApis::TokensApi* | [**get_contract_details_by_address**](docs/TokensApi.md#get_contract_details_by_address) | **GET** /blockchain-data/{blockchain}/{network}/addresses/{contractAddress}/contract | Get Contract Details by Address
*CryptoApis::TokensApi* | [**list_tokens_by_address**](docs/TokensApi.md#list_tokens_by_address) | **GET** /blockchain-data/{blockchain}/{network}/addresses/{address}/tokens | List Tokens By Address
*CryptoApis::TokensApi* | [**list_tokens_transfers_by_address**](docs/TokensApi.md#list_tokens_transfers_by_address) | **GET** /blockchain-data/{blockchain}/{network}/addresses/{address}/tokens-transfers | List Tokens Transfers By Address
*CryptoApis::TokensApi* | [**list_tokens_transfers_by_transaction_hash**](docs/TokensApi.md#list_tokens_transfers_by_transaction_hash) | **GET** /blockchain-data/{blockchain}/{network}/transactions/{transactionHash}/tokens-transfers | List Tokens Transfers By Transaction Hash
*CryptoApis::TransactionsApi* | [**create_coins_transaction_request_from_address**](docs/TransactionsApi.md#create_coins_transaction_request_from_address) | **POST** /wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses/{address}/transaction-requests | Create Coins Transaction Request from Address
*CryptoApis::TransactionsApi* | [**create_coins_transaction_request_from_wallet**](docs/TransactionsApi.md#create_coins_transaction_request_from_wallet) | **POST** /wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/transaction-requests | Create Coins Transaction Request from Wallet
*CryptoApis::TransactionsApi* | [**create_tokens_transaction_request_from_address**](docs/TransactionsApi.md#create_tokens_transaction_request_from_address) | **POST** /wallet-as-a-service/wallets/{walletId}/{blockchain}/{network}/addresses/{senderAddress}/token-transaction-requests | Create Tokens Transaction Request from Address
*CryptoApis::UTXOBasedApi* | [**get_hd_wallet__x_pub_y_pub_z_pub_details**](docs/UTXOBasedApi.md#get_hd_wallet__x_pub_y_pub_z_pub_details) | **GET** /blockchain-data/{blockchain}/{network}/hd/{extendedPublicKey}/details | Get HD Wallet (xPub, yPub, zPub) Details
*CryptoApis::UTXOBasedApi* | [**list_hd_wallet__x_pub_y_pub_z_pub_transactions**](docs/UTXOBasedApi.md#list_hd_wallet__x_pub_y_pub_z_pub_transactions) | **GET** /blockchain-data/{blockchain}/{network}/hd/{extendedPublicKey}/transactions | List HD Wallet (xPub, yPub, zPub) Transactions
*CryptoApis::UTXOBasedApi* | [**sync_hd_wallet__x_pub_y_pub_z_pub**](docs/UTXOBasedApi.md#sync_hd_wallet__x_pub_y_pub_z_pub) | **POST** /blockchain-data/{blockchain}/{network}/hd/sync | Sync HD Wallet (xPub, yPub, zPub)
*CryptoApis::UnifiedEndpointsApi* | [**get_address_details**](docs/UnifiedEndpointsApi.md#get_address_details) | **GET** /blockchain-data/{blockchain}/{network}/addresses/{address} | Get Address Details
*CryptoApis::UnifiedEndpointsApi* | [**get_block_details_by_block_hash**](docs/UnifiedEndpointsApi.md#get_block_details_by_block_hash) | **GET** /blockchain-data/{blockchain}/{network}/blocks/hash/{blockHash} | Get Block Details By Block Hash
*CryptoApis::UnifiedEndpointsApi* | [**get_block_details_by_block_height**](docs/UnifiedEndpointsApi.md#get_block_details_by_block_height) | **GET** /blockchain-data/{blockchain}/{network}/blocks/height/{height} | Get Block Details By Block Height
*CryptoApis::UnifiedEndpointsApi* | [**get_fee_recommendations**](docs/UnifiedEndpointsApi.md#get_fee_recommendations) | **GET** /blockchain-data/{blockchain}/{network}/mempool/fees | Get Fee Recommendations
*CryptoApis::UnifiedEndpointsApi* | [**get_latest_mined_block**](docs/UnifiedEndpointsApi.md#get_latest_mined_block) | **GET** /blockchain-data/{blockchain}/{network}/blocks/last | Get Latest Mined Block
*CryptoApis::UnifiedEndpointsApi* | [**get_transaction_details_by_transaction_id**](docs/UnifiedEndpointsApi.md#get_transaction_details_by_transaction_id) | **GET** /blockchain-data/{blockchain}/{network}/transactions/{transactionId} | Get Transaction Details By Transaction ID
*CryptoApis::UnifiedEndpointsApi* | [**list_transactions_by_address**](docs/UnifiedEndpointsApi.md#list_transactions_by_address) | **GET** /blockchain-data/{blockchain}/{network}/addresses/{address}/transactions | List Transactions By Address
*CryptoApis::UnifiedEndpointsApi* | [**list_transactions_by_block_hash**](docs/UnifiedEndpointsApi.md#list_transactions_by_block_hash) | **GET** /blockchain-data/{blockchain}/{network}/blocks/hash/{blockHash}/transactions | List Transactions by Block Hash
*CryptoApis::UnifiedEndpointsApi* | [**list_transactions_by_block_height**](docs/UnifiedEndpointsApi.md#list_transactions_by_block_height) | **GET** /blockchain-data/{blockchain}/{network}/blocks/height/{height}/transactions | List Transactions by Block Height
*CryptoApis::XRPRippleApi* | [**get_latest_mined_xrp__ripple_block**](docs/XRPRippleApi.md#get_latest_mined_xrp__ripple_block) | **GET** /blockchain-data/xrp-specific/{network}/blocks/last | Get Latest Mined XRP (Ripple) Block
*CryptoApis::XRPRippleApi* | [**get_xrp__ripple_address_details**](docs/XRPRippleApi.md#get_xrp__ripple_address_details) | **GET** /blockchain-data/xrp-specific/{network}/addresses/{address} | Get XRP (Ripple) Address Details
*CryptoApis::XRPRippleApi* | [**get_xrp__ripple_block_details_by_block_hash**](docs/XRPRippleApi.md#get_xrp__ripple_block_details_by_block_hash) | **GET** /blockchain-data/xrp-specific/{network}/blocks/hash/{blockHash} | Get XRP (Ripple) Block Details By Block Hash
*CryptoApis::XRPRippleApi* | [**get_xrp__ripple_block_details_by_block_height**](docs/XRPRippleApi.md#get_xrp__ripple_block_details_by_block_height) | **GET** /blockchain-data/xrp-specific/{network}/blocks/height/{blockHeight} | Get XRP (Ripple) Block Details By Block Height
*CryptoApis::XRPRippleApi* | [**get_xrp__ripple_transaction_details_by_transaction_id**](docs/XRPRippleApi.md#get_xrp__ripple_transaction_details_by_transaction_id) | **GET** /blockchain-data/xrp-specific/{network}/transactions/{transactionHash} | Get XRP (Ripple) Transaction Details By Transaction ID
*CryptoApis::XRPRippleApi* | [**list_xrp__ripple_transactions_by_address**](docs/XRPRippleApi.md#list_xrp__ripple_transactions_by_address) | **GET** /blockchain-data/xrp-specific/{network}/addresses/{address}/transactions | List XRP (Ripple) Transactions by Address
*CryptoApis::XRPRippleApi* | [**list_xrp__ripple_transactions_by_block_hash**](docs/XRPRippleApi.md#list_xrp__ripple_transactions_by_block_hash) | **GET** /blockchain-data/xrp-specific/{network}/blocks/hash/{blockHash}/transactions | List XRP (Ripple) Transactions By Block Hash
*CryptoApis::XRPRippleApi* | [**list_xrp__ripple_transactions_by_block_height**](docs/XRPRippleApi.md#list_xrp__ripple_transactions_by_block_height) | **GET** /blockchain-data/xrp-specific/{network}/blocks/height/{blockHeight}/transactions | List XRP (Ripple) Transactions By Block Height
*CryptoApis::ZilliqaApi* | [**get_latest_mined_zilliqa_block**](docs/ZilliqaApi.md#get_latest_mined_zilliqa_block) | **GET** /blockchain-data/zilliqa-specific/{network}/blocks/last | Get Latest Mined Zilliqa Block
*CryptoApis::ZilliqaApi* | [**get_zilliqa_address_details**](docs/ZilliqaApi.md#get_zilliqa_address_details) | **GET** /blockchain-data/zilliqa-specific/{network}/addresses/{address} | Get Zilliqa Address Details
*CryptoApis::ZilliqaApi* | [**get_zilliqa_block_details_by_block_hash**](docs/ZilliqaApi.md#get_zilliqa_block_details_by_block_hash) | **GET** /blockchain-data/zilliqa-specific/{network}/blocks/hash/{blockHash} | Get Zilliqa Block Details By Block Hash
*CryptoApis::ZilliqaApi* | [**get_zilliqa_block_details_by_block_height**](docs/ZilliqaApi.md#get_zilliqa_block_details_by_block_height) | **GET** /blockchain-data/zilliqa-specific/{network}/blocks/height/{blockHeight} | Get Zilliqa Block Details By Block Height
*CryptoApis::ZilliqaApi* | [**get_zilliqa_transaction_details_by_transaction_id**](docs/ZilliqaApi.md#get_zilliqa_transaction_details_by_transaction_id) | **GET** /blockchain-data/zilliqa-specific/{network}/transactions/{transactionHash} | Get Zilliqa Transaction Details by Transaction ID
*CryptoApis::ZilliqaApi* | [**list_zilliqa_transactions_by_address**](docs/ZilliqaApi.md#list_zilliqa_transactions_by_address) | **GET** /blockchain-data/zilliqa-specific/{network}/addresses/{address}/transactions | List Zilliqa Transactions by Address
*CryptoApis::ZilliqaApi* | [**list_zilliqa_transactions_by_block_hash**](docs/ZilliqaApi.md#list_zilliqa_transactions_by_block_hash) | **GET** /blockchain-data/zilliqa-specific/{network}/blocks/hash/{blockHash}/transactions | List Zilliqa Transactions By Block Hash
*CryptoApis::ZilliqaApi* | [**list_zilliqa_transactions_by_block_height**](docs/ZilliqaApi.md#list_zilliqa_transactions_by_block_height) | **GET** /blockchain-data/zilliqa-specific/{network}/blocks/height/{blockHeight}/transactions | List Zilliqa Transactions By Block Height


## Documentation for Models

 - [CryptoApis::AddTokensToExistingFromAddressR](docs/AddTokensToExistingFromAddressR.md)
 - [CryptoApis::AddTokensToExistingFromAddressRB](docs/AddTokensToExistingFromAddressRB.md)
 - [CryptoApis::AddTokensToExistingFromAddressRBData](docs/AddTokensToExistingFromAddressRBData.md)
 - [CryptoApis::AddTokensToExistingFromAddressRBDataItem](docs/AddTokensToExistingFromAddressRBDataItem.md)
 - [CryptoApis::AddTokensToExistingFromAddressRBTokenData](docs/AddTokensToExistingFromAddressRBTokenData.md)
 - [CryptoApis::AddTokensToExistingFromAddressRBTokenDataBitcoinOmniToken](docs/AddTokensToExistingFromAddressRBTokenDataBitcoinOmniToken.md)
 - [CryptoApis::AddTokensToExistingFromAddressRBTokenDataEthereumErc20Token](docs/AddTokensToExistingFromAddressRBTokenDataEthereumErc20Token.md)
 - [CryptoApis::AddTokensToExistingFromAddressRData](docs/AddTokensToExistingFromAddressRData.md)
 - [CryptoApis::AddTokensToExistingFromAddressRI](docs/AddTokensToExistingFromAddressRI.md)
 - [CryptoApis::AddTokensToExistingFromAddressRITS](docs/AddTokensToExistingFromAddressRITS.md)
 - [CryptoApis::AddTokensToExistingFromAddressRITSBOT](docs/AddTokensToExistingFromAddressRITSBOT.md)
 - [CryptoApis::AddTokensToExistingFromAddressRITSEET](docs/AddTokensToExistingFromAddressRITSEET.md)
 - [CryptoApis::AddressCoinsTransactionConfirmed](docs/AddressCoinsTransactionConfirmed.md)
 - [CryptoApis::AddressCoinsTransactionConfirmedData](docs/AddressCoinsTransactionConfirmedData.md)
 - [CryptoApis::AddressCoinsTransactionConfirmedDataItem](docs/AddressCoinsTransactionConfirmedDataItem.md)
 - [CryptoApis::AddressCoinsTransactionConfirmedDataItemMinedInBlock](docs/AddressCoinsTransactionConfirmedDataItemMinedInBlock.md)
 - [CryptoApis::AddressCoinsTransactionConfirmedEachConfirmation](docs/AddressCoinsTransactionConfirmedEachConfirmation.md)
 - [CryptoApis::AddressCoinsTransactionConfirmedEachConfirmationData](docs/AddressCoinsTransactionConfirmedEachConfirmationData.md)
 - [CryptoApis::AddressCoinsTransactionConfirmedEachConfirmationDataItem](docs/AddressCoinsTransactionConfirmedEachConfirmationDataItem.md)
 - [CryptoApis::AddressCoinsTransactionConfirmedEachConfirmationDataItemMinedInBlock](docs/AddressCoinsTransactionConfirmedEachConfirmationDataItemMinedInBlock.md)
 - [CryptoApis::AddressCoinsTransactionUnconfirmed](docs/AddressCoinsTransactionUnconfirmed.md)
 - [CryptoApis::AddressCoinsTransactionUnconfirmedData](docs/AddressCoinsTransactionUnconfirmedData.md)
 - [CryptoApis::AddressCoinsTransactionUnconfirmedDataItem](docs/AddressCoinsTransactionUnconfirmedDataItem.md)
 - [CryptoApis::AddressTokensTransactionConfirmed](docs/AddressTokensTransactionConfirmed.md)
 - [CryptoApis::AddressTokensTransactionConfirmedData](docs/AddressTokensTransactionConfirmedData.md)
 - [CryptoApis::AddressTokensTransactionConfirmedDataItem](docs/AddressTokensTransactionConfirmedDataItem.md)
 - [CryptoApis::AddressTokensTransactionConfirmedDataItemMinedInBlock](docs/AddressTokensTransactionConfirmedDataItemMinedInBlock.md)
 - [CryptoApis::AddressTokensTransactionConfirmedEachConfirmation](docs/AddressTokensTransactionConfirmedEachConfirmation.md)
 - [CryptoApis::AddressTokensTransactionConfirmedEachConfirmationData](docs/AddressTokensTransactionConfirmedEachConfirmationData.md)
 - [CryptoApis::AddressTokensTransactionConfirmedEachConfirmationDataItem](docs/AddressTokensTransactionConfirmedEachConfirmationDataItem.md)
 - [CryptoApis::AddressTokensTransactionConfirmedEachConfirmationDataItemMinedInBlock](docs/AddressTokensTransactionConfirmedEachConfirmationDataItemMinedInBlock.md)
 - [CryptoApis::AddressTokensTransactionConfirmedEachConfirmationEthereumerc20token](docs/AddressTokensTransactionConfirmedEachConfirmationEthereumerc20token.md)
 - [CryptoApis::AddressTokensTransactionConfirmedEachConfirmationEthereumerc721token](docs/AddressTokensTransactionConfirmedEachConfirmationEthereumerc721token.md)
 - [CryptoApis::AddressTokensTransactionConfirmedEachConfirmationOmnilayertoken](docs/AddressTokensTransactionConfirmedEachConfirmationOmnilayertoken.md)
 - [CryptoApis::AddressTokensTransactionConfirmedEachConfirmationToken](docs/AddressTokensTransactionConfirmedEachConfirmationToken.md)
 - [CryptoApis::AddressTokensTransactionConfirmedEthereumerc20token](docs/AddressTokensTransactionConfirmedEthereumerc20token.md)
 - [CryptoApis::AddressTokensTransactionConfirmedEthereumerc721token](docs/AddressTokensTransactionConfirmedEthereumerc721token.md)
 - [CryptoApis::AddressTokensTransactionConfirmedOmnilayertoken](docs/AddressTokensTransactionConfirmedOmnilayertoken.md)
 - [CryptoApis::AddressTokensTransactionConfirmedToken](docs/AddressTokensTransactionConfirmedToken.md)
 - [CryptoApis::AddressTokensTransactionUnconfirmed](docs/AddressTokensTransactionUnconfirmed.md)
 - [CryptoApis::AddressTokensTransactionUnconfirmedData](docs/AddressTokensTransactionUnconfirmedData.md)
 - [CryptoApis::AddressTokensTransactionUnconfirmedDataItem](docs/AddressTokensTransactionUnconfirmedDataItem.md)
 - [CryptoApis::AddressTokensTransactionUnconfirmedEthereumerc20token](docs/AddressTokensTransactionUnconfirmedEthereumerc20token.md)
 - [CryptoApis::AddressTokensTransactionUnconfirmedEthereumerc721token](docs/AddressTokensTransactionUnconfirmedEthereumerc721token.md)
 - [CryptoApis::AddressTokensTransactionUnconfirmedOmnilayertoken](docs/AddressTokensTransactionUnconfirmedOmnilayertoken.md)
 - [CryptoApis::AddressTokensTransactionUnconfirmedToken](docs/AddressTokensTransactionUnconfirmedToken.md)
 - [CryptoApis::AlreadyExists](docs/AlreadyExists.md)
 - [CryptoApis::AlreadyExistsError](docs/AlreadyExistsError.md)
 - [CryptoApis::BannedIpAddress](docs/BannedIpAddress.md)
 - [CryptoApis::BannedIpAddressError](docs/BannedIpAddressError.md)
 - [CryptoApis::BannedIpAddressErrorDetails](docs/BannedIpAddressErrorDetails.md)
 - [CryptoApis::BlockMined](docs/BlockMined.md)
 - [CryptoApis::BlockMinedData](docs/BlockMinedData.md)
 - [CryptoApis::BlockMinedDataItem](docs/BlockMinedDataItem.md)
 - [CryptoApis::BlockchainDataBlockNotFound](docs/BlockchainDataBlockNotFound.md)
 - [CryptoApis::BlockchainDataBlockNotFoundError](docs/BlockchainDataBlockNotFoundError.md)
 - [CryptoApis::BlockchainDataInternalTransactionNotFound](docs/BlockchainDataInternalTransactionNotFound.md)
 - [CryptoApis::BlockchainDataInternalTransactionNotFoundError](docs/BlockchainDataInternalTransactionNotFoundError.md)
 - [CryptoApis::BlockchainDataTransactionNotFound](docs/BlockchainDataTransactionNotFound.md)
 - [CryptoApis::BlockchainDataTransactionNotFoundError](docs/BlockchainDataTransactionNotFoundError.md)
 - [CryptoApis::BlockchainEventsCallbacksLimitReached](docs/BlockchainEventsCallbacksLimitReached.md)
 - [CryptoApis::BlockchainEventsCallbacksLimitReachedError](docs/BlockchainEventsCallbacksLimitReachedError.md)
 - [CryptoApis::BroadcastLocallySignedTransactionR](docs/BroadcastLocallySignedTransactionR.md)
 - [CryptoApis::BroadcastLocallySignedTransactionRB](docs/BroadcastLocallySignedTransactionRB.md)
 - [CryptoApis::BroadcastLocallySignedTransactionRBData](docs/BroadcastLocallySignedTransactionRBData.md)
 - [CryptoApis::BroadcastLocallySignedTransactionRBDataItem](docs/BroadcastLocallySignedTransactionRBDataItem.md)
 - [CryptoApis::BroadcastLocallySignedTransactionRData](docs/BroadcastLocallySignedTransactionRData.md)
 - [CryptoApis::BroadcastLocallySignedTransactionRI](docs/BroadcastLocallySignedTransactionRI.md)
 - [CryptoApis::BroadcastTransactionFail](docs/BroadcastTransactionFail.md)
 - [CryptoApis::BroadcastTransactionFailData](docs/BroadcastTransactionFailData.md)
 - [CryptoApis::BroadcastTransactionFailDataItem](docs/BroadcastTransactionFailDataItem.md)
 - [CryptoApis::BroadcastTransactionSuccess](docs/BroadcastTransactionSuccess.md)
 - [CryptoApis::BroadcastTransactionSuccessData](docs/BroadcastTransactionSuccessData.md)
 - [CryptoApis::BroadcastTransactionSuccessDataItem](docs/BroadcastTransactionSuccessDataItem.md)
 - [CryptoApis::CoinsForwardingAutomationsLimitReached](docs/CoinsForwardingAutomationsLimitReached.md)
 - [CryptoApis::CoinsForwardingAutomationsLimitReachedError](docs/CoinsForwardingAutomationsLimitReachedError.md)
 - [CryptoApis::CoinsForwardingFail](docs/CoinsForwardingFail.md)
 - [CryptoApis::CoinsForwardingFailData](docs/CoinsForwardingFailData.md)
 - [CryptoApis::CoinsForwardingFailDataItem](docs/CoinsForwardingFailDataItem.md)
 - [CryptoApis::CoinsForwardingSuccess](docs/CoinsForwardingSuccess.md)
 - [CryptoApis::CoinsForwardingSuccessData](docs/CoinsForwardingSuccessData.md)
 - [CryptoApis::CoinsForwardingSuccessDataItem](docs/CoinsForwardingSuccessDataItem.md)
 - [CryptoApis::CouldNotCalculateRateForPair](docs/CouldNotCalculateRateForPair.md)
 - [CryptoApis::CouldNotCalculateRateForPairError](docs/CouldNotCalculateRateForPairError.md)
 - [CryptoApis::CreateAutomaticCoinsForwardingR](docs/CreateAutomaticCoinsForwardingR.md)
 - [CryptoApis::CreateAutomaticCoinsForwardingRB](docs/CreateAutomaticCoinsForwardingRB.md)
 - [CryptoApis::CreateAutomaticCoinsForwardingRBData](docs/CreateAutomaticCoinsForwardingRBData.md)
 - [CryptoApis::CreateAutomaticCoinsForwardingRBDataItem](docs/CreateAutomaticCoinsForwardingRBDataItem.md)
 - [CryptoApis::CreateAutomaticCoinsForwardingRData](docs/CreateAutomaticCoinsForwardingRData.md)
 - [CryptoApis::CreateAutomaticCoinsForwardingRI](docs/CreateAutomaticCoinsForwardingRI.md)
 - [CryptoApis::CreateAutomaticTokensForwardingR](docs/CreateAutomaticTokensForwardingR.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRB](docs/CreateAutomaticTokensForwardingRB.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRBData](docs/CreateAutomaticTokensForwardingRBData.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRBDataItem](docs/CreateAutomaticTokensForwardingRBDataItem.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRBTokenData](docs/CreateAutomaticTokensForwardingRBTokenData.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRBTokenDataBitcoinOmniToken](docs/CreateAutomaticTokensForwardingRBTokenDataBitcoinOmniToken.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRBTokenDataEthereumToken](docs/CreateAutomaticTokensForwardingRBTokenDataEthereumToken.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRData](docs/CreateAutomaticTokensForwardingRData.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRI](docs/CreateAutomaticTokensForwardingRI.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRITS](docs/CreateAutomaticTokensForwardingRITS.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRITSBOT](docs/CreateAutomaticTokensForwardingRITSBOT.md)
 - [CryptoApis::CreateAutomaticTokensForwardingRITSET](docs/CreateAutomaticTokensForwardingRITSET.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromAddressR](docs/CreateCoinsTransactionRequestFromAddressR.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromAddressRB](docs/CreateCoinsTransactionRequestFromAddressRB.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromAddressRBData](docs/CreateCoinsTransactionRequestFromAddressRBData.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromAddressRBDataItem](docs/CreateCoinsTransactionRequestFromAddressRBDataItem.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromAddressRData](docs/CreateCoinsTransactionRequestFromAddressRData.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromAddressRI](docs/CreateCoinsTransactionRequestFromAddressRI.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromAddressRIRecipients](docs/CreateCoinsTransactionRequestFromAddressRIRecipients.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromAddressRISenders](docs/CreateCoinsTransactionRequestFromAddressRISenders.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromWalletR](docs/CreateCoinsTransactionRequestFromWalletR.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromWalletRB](docs/CreateCoinsTransactionRequestFromWalletRB.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromWalletRBData](docs/CreateCoinsTransactionRequestFromWalletRBData.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromWalletRBDataItem](docs/CreateCoinsTransactionRequestFromWalletRBDataItem.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromWalletRBDataItemRecipients](docs/CreateCoinsTransactionRequestFromWalletRBDataItemRecipients.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromWalletRData](docs/CreateCoinsTransactionRequestFromWalletRData.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromWalletRI](docs/CreateCoinsTransactionRequestFromWalletRI.md)
 - [CryptoApis::CreateCoinsTransactionRequestFromWalletRIRecipients](docs/CreateCoinsTransactionRequestFromWalletRIRecipients.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressR](docs/CreateTokensTransactionRequestFromAddressR.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressRB](docs/CreateTokensTransactionRequestFromAddressRB.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressRBData](docs/CreateTokensTransactionRequestFromAddressRBData.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressRBDataItem](docs/CreateTokensTransactionRequestFromAddressRBDataItem.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressRData](docs/CreateTokensTransactionRequestFromAddressRData.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressRI](docs/CreateTokensTransactionRequestFromAddressRI.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressRIRecipients](docs/CreateTokensTransactionRequestFromAddressRIRecipients.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressRIS](docs/CreateTokensTransactionRequestFromAddressRIS.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressRISB](docs/CreateTokensTransactionRequestFromAddressRISB.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressRISE](docs/CreateTokensTransactionRequestFromAddressRISE.md)
 - [CryptoApis::CreateTokensTransactionRequestFromAddressRISenders](docs/CreateTokensTransactionRequestFromAddressRISenders.md)
 - [CryptoApis::DeleteAutomaticCoinsForwardingR](docs/DeleteAutomaticCoinsForwardingR.md)
 - [CryptoApis::DeleteAutomaticCoinsForwardingRData](docs/DeleteAutomaticCoinsForwardingRData.md)
 - [CryptoApis::DeleteAutomaticCoinsForwardingRI](docs/DeleteAutomaticCoinsForwardingRI.md)
 - [CryptoApis::DeleteAutomaticTokensForwardingR](docs/DeleteAutomaticTokensForwardingR.md)
 - [CryptoApis::DeleteAutomaticTokensForwardingRData](docs/DeleteAutomaticTokensForwardingRData.md)
 - [CryptoApis::DeleteAutomaticTokensForwardingRI](docs/DeleteAutomaticTokensForwardingRI.md)
 - [CryptoApis::DeleteAutomaticTokensForwardingRITS](docs/DeleteAutomaticTokensForwardingRITS.md)
 - [CryptoApis::DeleteAutomaticTokensForwardingRITSBOT](docs/DeleteAutomaticTokensForwardingRITSBOT.md)
 - [CryptoApis::DeleteAutomaticTokensForwardingRITSET](docs/DeleteAutomaticTokensForwardingRITSET.md)
 - [CryptoApis::DeleteBlockchainEventSubscriptionR](docs/DeleteBlockchainEventSubscriptionR.md)
 - [CryptoApis::DeleteBlockchainEventSubscriptionRData](docs/DeleteBlockchainEventSubscriptionRData.md)
 - [CryptoApis::DeleteBlockchainEventSubscriptionRI](docs/DeleteBlockchainEventSubscriptionRI.md)
 - [CryptoApis::EndpointNotAllowedForApiKey](docs/EndpointNotAllowedForApiKey.md)
 - [CryptoApis::EndpointNotAllowedForApiKeyError](docs/EndpointNotAllowedForApiKeyError.md)
 - [CryptoApis::EndpointNotAllowedForPlan](docs/EndpointNotAllowedForPlan.md)
 - [CryptoApis::EndpointNotAllowedForPlanError](docs/EndpointNotAllowedForPlanError.md)
 - [CryptoApis::FeatureMainnetsNotAllowedForPlan](docs/FeatureMainnetsNotAllowedForPlan.md)
 - [CryptoApis::FeatureMainnetsNotAllowedForPlanError](docs/FeatureMainnetsNotAllowedForPlanError.md)
 - [CryptoApis::GenerateDepositAddressR](docs/GenerateDepositAddressR.md)
 - [CryptoApis::GenerateDepositAddressRB](docs/GenerateDepositAddressRB.md)
 - [CryptoApis::GenerateDepositAddressRBData](docs/GenerateDepositAddressRBData.md)
 - [CryptoApis::GenerateDepositAddressRBDataItem](docs/GenerateDepositAddressRBDataItem.md)
 - [CryptoApis::GenerateDepositAddressRData](docs/GenerateDepositAddressRData.md)
 - [CryptoApis::GenerateDepositAddressRI](docs/GenerateDepositAddressRI.md)
 - [CryptoApis::GetAddressDetailsR](docs/GetAddressDetailsR.md)
 - [CryptoApis::GetAddressDetailsRData](docs/GetAddressDetailsRData.md)
 - [CryptoApis::GetAddressDetailsRI](docs/GetAddressDetailsRI.md)
 - [CryptoApis::GetAddressDetailsRIConfirmedBalance](docs/GetAddressDetailsRIConfirmedBalance.md)
 - [CryptoApis::GetAddressDetailsRITotalReceived](docs/GetAddressDetailsRITotalReceived.md)
 - [CryptoApis::GetAddressDetailsRITotalSpent](docs/GetAddressDetailsRITotalSpent.md)
 - [CryptoApis::GetBlockDetailsByBlockHashR](docs/GetBlockDetailsByBlockHashR.md)
 - [CryptoApis::GetBlockDetailsByBlockHashRData](docs/GetBlockDetailsByBlockHashRData.md)
 - [CryptoApis::GetBlockDetailsByBlockHashRI](docs/GetBlockDetailsByBlockHashRI.md)
 - [CryptoApis::GetBlockDetailsByBlockHashRIBS](docs/GetBlockDetailsByBlockHashRIBS.md)
 - [CryptoApis::GetBlockDetailsByBlockHashRIBSB](docs/GetBlockDetailsByBlockHashRIBSB.md)
 - [CryptoApis::GetBlockDetailsByBlockHashRIBSBC](docs/GetBlockDetailsByBlockHashRIBSBC.md)
 - [CryptoApis::GetBlockDetailsByBlockHashRIBSD](docs/GetBlockDetailsByBlockHashRIBSD.md)
 - [CryptoApis::GetBlockDetailsByBlockHashRIBSD2](docs/GetBlockDetailsByBlockHashRIBSD2.md)
 - [CryptoApis::GetBlockDetailsByBlockHashRIBSE](docs/GetBlockDetailsByBlockHashRIBSE.md)
 - [CryptoApis::GetBlockDetailsByBlockHashRIBSEC](docs/GetBlockDetailsByBlockHashRIBSEC.md)
 - [CryptoApis::GetBlockDetailsByBlockHashRIBSL](docs/GetBlockDetailsByBlockHashRIBSL.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightR](docs/GetBlockDetailsByBlockHeightR.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightRData](docs/GetBlockDetailsByBlockHeightRData.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightRI](docs/GetBlockDetailsByBlockHeightRI.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightRIBS](docs/GetBlockDetailsByBlockHeightRIBS.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightRIBSB](docs/GetBlockDetailsByBlockHeightRIBSB.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightRIBSBC](docs/GetBlockDetailsByBlockHeightRIBSBC.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightRIBSD](docs/GetBlockDetailsByBlockHeightRIBSD.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightRIBSD2](docs/GetBlockDetailsByBlockHeightRIBSD2.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightRIBSE](docs/GetBlockDetailsByBlockHeightRIBSE.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightRIBSEC](docs/GetBlockDetailsByBlockHeightRIBSEC.md)
 - [CryptoApis::GetBlockDetailsByBlockHeightRIBSL](docs/GetBlockDetailsByBlockHeightRIBSL.md)
 - [CryptoApis::GetContractDetailsByAddressR](docs/GetContractDetailsByAddressR.md)
 - [CryptoApis::GetContractDetailsByAddressRData](docs/GetContractDetailsByAddressRData.md)
 - [CryptoApis::GetContractDetailsByAddressRI](docs/GetContractDetailsByAddressRI.md)
 - [CryptoApis::GetExchangeRateByAssetSymbolsR](docs/GetExchangeRateByAssetSymbolsR.md)
 - [CryptoApis::GetExchangeRateByAssetSymbolsRData](docs/GetExchangeRateByAssetSymbolsRData.md)
 - [CryptoApis::GetExchangeRateByAssetSymbolsRI](docs/GetExchangeRateByAssetSymbolsRI.md)
 - [CryptoApis::GetExchangeRateByAssetsIDsR](docs/GetExchangeRateByAssetsIDsR.md)
 - [CryptoApis::GetExchangeRateByAssetsIDsRData](docs/GetExchangeRateByAssetsIDsRData.md)
 - [CryptoApis::GetExchangeRateByAssetsIDsRI](docs/GetExchangeRateByAssetsIDsRI.md)
 - [CryptoApis::GetFeeAddressDetailsR](docs/GetFeeAddressDetailsR.md)
 - [CryptoApis::GetFeeAddressDetailsRData](docs/GetFeeAddressDetailsRData.md)
 - [CryptoApis::GetFeeAddressDetailsRI](docs/GetFeeAddressDetailsRI.md)
 - [CryptoApis::GetFeeAddressDetailsRIBalance](docs/GetFeeAddressDetailsRIBalance.md)
 - [CryptoApis::GetFeeRecommendationsR](docs/GetFeeRecommendationsR.md)
 - [CryptoApis::GetFeeRecommendationsRData](docs/GetFeeRecommendationsRData.md)
 - [CryptoApis::GetFeeRecommendationsRI](docs/GetFeeRecommendationsRI.md)
 - [CryptoApis::GetHDWalletXPubYPubZPubDetailsR](docs/GetHDWalletXPubYPubZPubDetailsR.md)
 - [CryptoApis::GetHDWalletXPubYPubZPubDetailsRData](docs/GetHDWalletXPubYPubZPubDetailsRData.md)
 - [CryptoApis::GetHDWalletXPubYPubZPubDetailsRI](docs/GetHDWalletXPubYPubZPubDetailsRI.md)
 - [CryptoApis::GetInternalTransactionByTransactionHashAndOperationIdR](docs/GetInternalTransactionByTransactionHashAndOperationIdR.md)
 - [CryptoApis::GetInternalTransactionByTransactionHashAndOperationIdRData](docs/GetInternalTransactionByTransactionHashAndOperationIdRData.md)
 - [CryptoApis::GetInternalTransactionByTransactionHashAndOperationIdRI](docs/GetInternalTransactionByTransactionHashAndOperationIdRI.md)
 - [CryptoApis::GetLatestMinedBlockR](docs/GetLatestMinedBlockR.md)
 - [CryptoApis::GetLatestMinedBlockRData](docs/GetLatestMinedBlockRData.md)
 - [CryptoApis::GetLatestMinedBlockRI](docs/GetLatestMinedBlockRI.md)
 - [CryptoApis::GetLatestMinedBlockRIBS](docs/GetLatestMinedBlockRIBS.md)
 - [CryptoApis::GetLatestMinedBlockRIBSB](docs/GetLatestMinedBlockRIBSB.md)
 - [CryptoApis::GetLatestMinedBlockRIBSBC](docs/GetLatestMinedBlockRIBSBC.md)
 - [CryptoApis::GetLatestMinedBlockRIBSD](docs/GetLatestMinedBlockRIBSD.md)
 - [CryptoApis::GetLatestMinedBlockRIBSD2](docs/GetLatestMinedBlockRIBSD2.md)
 - [CryptoApis::GetLatestMinedBlockRIBSE](docs/GetLatestMinedBlockRIBSE.md)
 - [CryptoApis::GetLatestMinedBlockRIBSEC](docs/GetLatestMinedBlockRIBSEC.md)
 - [CryptoApis::GetLatestMinedBlockRIBSL](docs/GetLatestMinedBlockRIBSL.md)
 - [CryptoApis::GetLatestMinedXRPRippleBlockR](docs/GetLatestMinedXRPRippleBlockR.md)
 - [CryptoApis::GetLatestMinedXRPRippleBlockRData](docs/GetLatestMinedXRPRippleBlockRData.md)
 - [CryptoApis::GetLatestMinedXRPRippleBlockRI](docs/GetLatestMinedXRPRippleBlockRI.md)
 - [CryptoApis::GetLatestMinedXRPRippleBlockRITotalCoins](docs/GetLatestMinedXRPRippleBlockRITotalCoins.md)
 - [CryptoApis::GetLatestMinedXRPRippleBlockRITotalFees](docs/GetLatestMinedXRPRippleBlockRITotalFees.md)
 - [CryptoApis::GetLatestMinedZilliqaBlockR](docs/GetLatestMinedZilliqaBlockR.md)
 - [CryptoApis::GetLatestMinedZilliqaBlockRData](docs/GetLatestMinedZilliqaBlockRData.md)
 - [CryptoApis::GetLatestMinedZilliqaBlockRI](docs/GetLatestMinedZilliqaBlockRI.md)
 - [CryptoApis::GetOmniTransactionDetailsByTransactionIDTxidR](docs/GetOmniTransactionDetailsByTransactionIDTxidR.md)
 - [CryptoApis::GetOmniTransactionDetailsByTransactionIDTxidRData](docs/GetOmniTransactionDetailsByTransactionIDTxidRData.md)
 - [CryptoApis::GetOmniTransactionDetailsByTransactionIDTxidRI](docs/GetOmniTransactionDetailsByTransactionIDTxidRI.md)
 - [CryptoApis::GetOmniTransactionDetailsByTransactionIDTxidRISenders](docs/GetOmniTransactionDetailsByTransactionIDTxidRISenders.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDR](docs/GetTransactionDetailsByTransactionIDR.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRData](docs/GetTransactionDetailsByTransactionIDRData.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRI](docs/GetTransactionDetailsByTransactionIDRI.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBS](docs/GetTransactionDetailsByTransactionIDRIBS.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSB](docs/GetTransactionDetailsByTransactionIDRIBSB.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSBC](docs/GetTransactionDetailsByTransactionIDRIBSBC.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSBCScriptPubKey](docs/GetTransactionDetailsByTransactionIDRIBSBCScriptPubKey.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSBCVin](docs/GetTransactionDetailsByTransactionIDRIBSBCVin.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSBCVout](docs/GetTransactionDetailsByTransactionIDRIBSBCVout.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSBScriptPubKey](docs/GetTransactionDetailsByTransactionIDRIBSBScriptPubKey.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSBScriptSig](docs/GetTransactionDetailsByTransactionIDRIBSBScriptSig.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSBVin](docs/GetTransactionDetailsByTransactionIDRIBSBVin.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSBVout](docs/GetTransactionDetailsByTransactionIDRIBSBVout.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSD](docs/GetTransactionDetailsByTransactionIDRIBSD.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSD2](docs/GetTransactionDetailsByTransactionIDRIBSD2.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSD2ScriptPubKey](docs/GetTransactionDetailsByTransactionIDRIBSD2ScriptPubKey.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSD2ScriptSig](docs/GetTransactionDetailsByTransactionIDRIBSD2ScriptSig.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSD2Vin](docs/GetTransactionDetailsByTransactionIDRIBSD2Vin.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSD2Vout](docs/GetTransactionDetailsByTransactionIDRIBSD2Vout.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSDScriptPubKey](docs/GetTransactionDetailsByTransactionIDRIBSDScriptPubKey.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSDScriptSig](docs/GetTransactionDetailsByTransactionIDRIBSDScriptSig.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSDVin](docs/GetTransactionDetailsByTransactionIDRIBSDVin.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSDVout](docs/GetTransactionDetailsByTransactionIDRIBSDVout.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSE](docs/GetTransactionDetailsByTransactionIDRIBSE.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSEC](docs/GetTransactionDetailsByTransactionIDRIBSEC.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSECGasPrice](docs/GetTransactionDetailsByTransactionIDRIBSECGasPrice.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSEGasPrice](docs/GetTransactionDetailsByTransactionIDRIBSEGasPrice.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSL](docs/GetTransactionDetailsByTransactionIDRIBSL.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSLScriptPubKey](docs/GetTransactionDetailsByTransactionIDRIBSLScriptPubKey.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSLScriptSig](docs/GetTransactionDetailsByTransactionIDRIBSLScriptSig.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSLVin](docs/GetTransactionDetailsByTransactionIDRIBSLVin.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIBSLVout](docs/GetTransactionDetailsByTransactionIDRIBSLVout.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIFee](docs/GetTransactionDetailsByTransactionIDRIFee.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRIRecipients](docs/GetTransactionDetailsByTransactionIDRIRecipients.md)
 - [CryptoApis::GetTransactionDetailsByTransactionIDRISenders](docs/GetTransactionDetailsByTransactionIDRISenders.md)
 - [CryptoApis::GetUnconfirmedOmniTransactionByTransactionIDTxidR](docs/GetUnconfirmedOmniTransactionByTransactionIDTxidR.md)
 - [CryptoApis::GetUnconfirmedOmniTransactionByTransactionIDTxidRData](docs/GetUnconfirmedOmniTransactionByTransactionIDTxidRData.md)
 - [CryptoApis::GetUnconfirmedOmniTransactionByTransactionIDTxidRI](docs/GetUnconfirmedOmniTransactionByTransactionIDTxidRI.md)
 - [CryptoApis::GetUnconfirmedOmniTransactionByTransactionIDTxidRIRecipients](docs/GetUnconfirmedOmniTransactionByTransactionIDTxidRIRecipients.md)
 - [CryptoApis::GetUnconfirmedOmniTransactionByTransactionIDTxidRISenders](docs/GetUnconfirmedOmniTransactionByTransactionIDTxidRISenders.md)
 - [CryptoApis::GetWalletAssetDetailsR](docs/GetWalletAssetDetailsR.md)
 - [CryptoApis::GetWalletAssetDetailsRData](docs/GetWalletAssetDetailsRData.md)
 - [CryptoApis::GetWalletAssetDetailsRI](docs/GetWalletAssetDetailsRI.md)
 - [CryptoApis::GetWalletAssetDetailsRIConfirmedBalance](docs/GetWalletAssetDetailsRIConfirmedBalance.md)
 - [CryptoApis::GetWalletAssetDetailsRIRecievedConfirmedAmount](docs/GetWalletAssetDetailsRIRecievedConfirmedAmount.md)
 - [CryptoApis::GetWalletAssetDetailsRISentConfirmedAmount](docs/GetWalletAssetDetailsRISentConfirmedAmount.md)
 - [CryptoApis::GetXRPRippleAddressDetailsR](docs/GetXRPRippleAddressDetailsR.md)
 - [CryptoApis::GetXRPRippleAddressDetailsRData](docs/GetXRPRippleAddressDetailsRData.md)
 - [CryptoApis::GetXRPRippleAddressDetailsRI](docs/GetXRPRippleAddressDetailsRI.md)
 - [CryptoApis::GetXRPRippleAddressDetailsRIBalance](docs/GetXRPRippleAddressDetailsRIBalance.md)
 - [CryptoApis::GetXRPRippleBlockDetailsByBlockHashR](docs/GetXRPRippleBlockDetailsByBlockHashR.md)
 - [CryptoApis::GetXRPRippleBlockDetailsByBlockHashRData](docs/GetXRPRippleBlockDetailsByBlockHashRData.md)
 - [CryptoApis::GetXRPRippleBlockDetailsByBlockHashRI](docs/GetXRPRippleBlockDetailsByBlockHashRI.md)
 - [CryptoApis::GetXRPRippleBlockDetailsByBlockHashRITotalCoins](docs/GetXRPRippleBlockDetailsByBlockHashRITotalCoins.md)
 - [CryptoApis::GetXRPRippleBlockDetailsByBlockHeightR](docs/GetXRPRippleBlockDetailsByBlockHeightR.md)
 - [CryptoApis::GetXRPRippleBlockDetailsByBlockHeightRData](docs/GetXRPRippleBlockDetailsByBlockHeightRData.md)
 - [CryptoApis::GetXRPRippleBlockDetailsByBlockHeightRI](docs/GetXRPRippleBlockDetailsByBlockHeightRI.md)
 - [CryptoApis::GetXRPRippleBlockDetailsByBlockHeightRITotalCoins](docs/GetXRPRippleBlockDetailsByBlockHeightRITotalCoins.md)
 - [CryptoApis::GetXRPRippleBlockDetailsByBlockHeightRITotalFees](docs/GetXRPRippleBlockDetailsByBlockHeightRITotalFees.md)
 - [CryptoApis::GetXRPRippleTransactionDetailsByTransactionIDR](docs/GetXRPRippleTransactionDetailsByTransactionIDR.md)
 - [CryptoApis::GetXRPRippleTransactionDetailsByTransactionIDRData](docs/GetXRPRippleTransactionDetailsByTransactionIDRData.md)
 - [CryptoApis::GetXRPRippleTransactionDetailsByTransactionIDRI](docs/GetXRPRippleTransactionDetailsByTransactionIDRI.md)
 - [CryptoApis::GetXRPRippleTransactionDetailsByTransactionIDRIFee](docs/GetXRPRippleTransactionDetailsByTransactionIDRIFee.md)
 - [CryptoApis::GetXRPRippleTransactionDetailsByTransactionIDRIOffer](docs/GetXRPRippleTransactionDetailsByTransactionIDRIOffer.md)
 - [CryptoApis::GetXRPRippleTransactionDetailsByTransactionIDRIReceive](docs/GetXRPRippleTransactionDetailsByTransactionIDRIReceive.md)
 - [CryptoApis::GetXRPRippleTransactionDetailsByTransactionIDRIRecipients](docs/GetXRPRippleTransactionDetailsByTransactionIDRIRecipients.md)
 - [CryptoApis::GetXRPRippleTransactionDetailsByTransactionIDRISenders](docs/GetXRPRippleTransactionDetailsByTransactionIDRISenders.md)
 - [CryptoApis::GetXRPRippleTransactionDetailsByTransactionIDRIValue](docs/GetXRPRippleTransactionDetailsByTransactionIDRIValue.md)
 - [CryptoApis::GetZilliqaAddressDetailsR](docs/GetZilliqaAddressDetailsR.md)
 - [CryptoApis::GetZilliqaAddressDetailsRData](docs/GetZilliqaAddressDetailsRData.md)
 - [CryptoApis::GetZilliqaAddressDetailsRI](docs/GetZilliqaAddressDetailsRI.md)
 - [CryptoApis::GetZilliqaAddressDetailsRIBalance](docs/GetZilliqaAddressDetailsRIBalance.md)
 - [CryptoApis::GetZilliqaBlockDetailsByBlockHashR](docs/GetZilliqaBlockDetailsByBlockHashR.md)
 - [CryptoApis::GetZilliqaBlockDetailsByBlockHashRData](docs/GetZilliqaBlockDetailsByBlockHashRData.md)
 - [CryptoApis::GetZilliqaBlockDetailsByBlockHashRI](docs/GetZilliqaBlockDetailsByBlockHashRI.md)
 - [CryptoApis::GetZilliqaBlockDetailsByBlockHeightR](docs/GetZilliqaBlockDetailsByBlockHeightR.md)
 - [CryptoApis::GetZilliqaBlockDetailsByBlockHeightRData](docs/GetZilliqaBlockDetailsByBlockHeightRData.md)
 - [CryptoApis::GetZilliqaBlockDetailsByBlockHeightRI](docs/GetZilliqaBlockDetailsByBlockHeightRI.md)
 - [CryptoApis::GetZilliqaTransactionDetailsByTransactionIDR](docs/GetZilliqaTransactionDetailsByTransactionIDR.md)
 - [CryptoApis::GetZilliqaTransactionDetailsByTransactionIDRData](docs/GetZilliqaTransactionDetailsByTransactionIDRData.md)
 - [CryptoApis::GetZilliqaTransactionDetailsByTransactionIDRI](docs/GetZilliqaTransactionDetailsByTransactionIDRI.md)
 - [CryptoApis::GetZilliqaTransactionDetailsByTransactionIDRIFee](docs/GetZilliqaTransactionDetailsByTransactionIDRIFee.md)
 - [CryptoApis::GetZilliqaTransactionDetailsByTransactionIDRIRecipients](docs/GetZilliqaTransactionDetailsByTransactionIDRIRecipients.md)
 - [CryptoApis::GetZilliqaTransactionDetailsByTransactionIDRISenders](docs/GetZilliqaTransactionDetailsByTransactionIDRISenders.md)
 - [CryptoApis::InsufficientCredits](docs/InsufficientCredits.md)
 - [CryptoApis::InsufficientCreditsError](docs/InsufficientCreditsError.md)
 - [CryptoApis::InvalidApiKey](docs/InvalidApiKey.md)
 - [CryptoApis::InvalidApiKeyError](docs/InvalidApiKeyError.md)
 - [CryptoApis::InvalidBlockchain](docs/InvalidBlockchain.md)
 - [CryptoApis::InvalidBlockchainError](docs/InvalidBlockchainError.md)
 - [CryptoApis::InvalidData](docs/InvalidData.md)
 - [CryptoApis::InvalidDataError](docs/InvalidDataError.md)
 - [CryptoApis::InvalidNetwork](docs/InvalidNetwork.md)
 - [CryptoApis::InvalidNetworkError](docs/InvalidNetworkError.md)
 - [CryptoApis::InvalidPagination](docs/InvalidPagination.md)
 - [CryptoApis::InvalidPaginationError](docs/InvalidPaginationError.md)
 - [CryptoApis::InvalidRequestBodyStructure](docs/InvalidRequestBodyStructure.md)
 - [CryptoApis::InvalidRequestBodyStructureError](docs/InvalidRequestBodyStructureError.md)
 - [CryptoApis::InvalidXpub](docs/InvalidXpub.md)
 - [CryptoApis::InvalidXpubError](docs/InvalidXpubError.md)
 - [CryptoApis::LimitGreaterThanAllowed](docs/LimitGreaterThanAllowed.md)
 - [CryptoApis::LimitGreaterThanAllowedError](docs/LimitGreaterThanAllowedError.md)
 - [CryptoApis::ListAssetsDetailsR](docs/ListAssetsDetailsR.md)
 - [CryptoApis::ListAssetsDetailsRData](docs/ListAssetsDetailsRData.md)
 - [CryptoApis::ListAssetsDetailsRI](docs/ListAssetsDetailsRI.md)
 - [CryptoApis::ListAssetsDetailsRIAssetLogo](docs/ListAssetsDetailsRIAssetLogo.md)
 - [CryptoApis::ListAssetsDetailsRILatestRate](docs/ListAssetsDetailsRILatestRate.md)
 - [CryptoApis::ListAssetsDetailsRIS](docs/ListAssetsDetailsRIS.md)
 - [CryptoApis::ListAssetsDetailsRISC](docs/ListAssetsDetailsRISC.md)
 - [CryptoApis::ListBlockchainEventsSubscriptionsR](docs/ListBlockchainEventsSubscriptionsR.md)
 - [CryptoApis::ListBlockchainEventsSubscriptionsRData](docs/ListBlockchainEventsSubscriptionsRData.md)
 - [CryptoApis::ListBlockchainEventsSubscriptionsRI](docs/ListBlockchainEventsSubscriptionsRI.md)
 - [CryptoApis::ListCoinsForwardingAutomationsR](docs/ListCoinsForwardingAutomationsR.md)
 - [CryptoApis::ListCoinsForwardingAutomationsRData](docs/ListCoinsForwardingAutomationsRData.md)
 - [CryptoApis::ListCoinsForwardingAutomationsRI](docs/ListCoinsForwardingAutomationsRI.md)
 - [CryptoApis::ListDepositAddressesR](docs/ListDepositAddressesR.md)
 - [CryptoApis::ListDepositAddressesRData](docs/ListDepositAddressesRData.md)
 - [CryptoApis::ListDepositAddressesRI](docs/ListDepositAddressesRI.md)
 - [CryptoApis::ListHDWalletXPubYPubZPubTransactionsR](docs/ListHDWalletXPubYPubZPubTransactionsR.md)
 - [CryptoApis::ListHDWalletXPubYPubZPubTransactionsRData](docs/ListHDWalletXPubYPubZPubTransactionsRData.md)
 - [CryptoApis::ListHDWalletXPubYPubZPubTransactionsRI](docs/ListHDWalletXPubYPubZPubTransactionsRI.md)
 - [CryptoApis::ListHDWalletXPubYPubZPubTransactionsRIFee](docs/ListHDWalletXPubYPubZPubTransactionsRIFee.md)
 - [CryptoApis::ListHDWalletXPubYPubZPubTransactionsRIRecipients](docs/ListHDWalletXPubYPubZPubTransactionsRIRecipients.md)
 - [CryptoApis::ListHDWalletXPubYPubZPubTransactionsRISenders](docs/ListHDWalletXPubYPubZPubTransactionsRISenders.md)
 - [CryptoApis::ListInternalTransactionDetailsByTransactionHashR](docs/ListInternalTransactionDetailsByTransactionHashR.md)
 - [CryptoApis::ListInternalTransactionDetailsByTransactionHashRData](docs/ListInternalTransactionDetailsByTransactionHashRData.md)
 - [CryptoApis::ListInternalTransactionDetailsByTransactionHashRI](docs/ListInternalTransactionDetailsByTransactionHashRI.md)
 - [CryptoApis::ListOmniTokensByAddressR](docs/ListOmniTokensByAddressR.md)
 - [CryptoApis::ListOmniTokensByAddressRData](docs/ListOmniTokensByAddressRData.md)
 - [CryptoApis::ListOmniTokensByAddressRI](docs/ListOmniTokensByAddressRI.md)
 - [CryptoApis::ListOmniTransactionsByAddressR](docs/ListOmniTransactionsByAddressR.md)
 - [CryptoApis::ListOmniTransactionsByAddressRData](docs/ListOmniTransactionsByAddressRData.md)
 - [CryptoApis::ListOmniTransactionsByAddressRI](docs/ListOmniTransactionsByAddressRI.md)
 - [CryptoApis::ListOmniTransactionsByAddressRIFee](docs/ListOmniTransactionsByAddressRIFee.md)
 - [CryptoApis::ListOmniTransactionsByAddressRIRecipients](docs/ListOmniTransactionsByAddressRIRecipients.md)
 - [CryptoApis::ListOmniTransactionsByAddressRISenders](docs/ListOmniTransactionsByAddressRISenders.md)
 - [CryptoApis::ListOmniTransactionsByBlockHashR](docs/ListOmniTransactionsByBlockHashR.md)
 - [CryptoApis::ListOmniTransactionsByBlockHashRData](docs/ListOmniTransactionsByBlockHashRData.md)
 - [CryptoApis::ListOmniTransactionsByBlockHashRI](docs/ListOmniTransactionsByBlockHashRI.md)
 - [CryptoApis::ListOmniTransactionsByBlockHashRIFee](docs/ListOmniTransactionsByBlockHashRIFee.md)
 - [CryptoApis::ListOmniTransactionsByBlockHeightR](docs/ListOmniTransactionsByBlockHeightR.md)
 - [CryptoApis::ListOmniTransactionsByBlockHeightRData](docs/ListOmniTransactionsByBlockHeightRData.md)
 - [CryptoApis::ListOmniTransactionsByBlockHeightRI](docs/ListOmniTransactionsByBlockHeightRI.md)
 - [CryptoApis::ListOmniTransactionsByBlockHeightRIFee](docs/ListOmniTransactionsByBlockHeightRIFee.md)
 - [CryptoApis::ListOmniTransactionsByBlockHeightRIRecipients](docs/ListOmniTransactionsByBlockHeightRIRecipients.md)
 - [CryptoApis::ListOmniTransactionsByBlockHeightRISenders](docs/ListOmniTransactionsByBlockHeightRISenders.md)
 - [CryptoApis::ListSupportedAssetsR](docs/ListSupportedAssetsR.md)
 - [CryptoApis::ListSupportedAssetsRData](docs/ListSupportedAssetsRData.md)
 - [CryptoApis::ListSupportedAssetsRI](docs/ListSupportedAssetsRI.md)
 - [CryptoApis::ListSupportedTokensR](docs/ListSupportedTokensR.md)
 - [CryptoApis::ListSupportedTokensRData](docs/ListSupportedTokensRData.md)
 - [CryptoApis::ListSupportedTokensRI](docs/ListSupportedTokensRI.md)
 - [CryptoApis::ListTokensByAddressR](docs/ListTokensByAddressR.md)
 - [CryptoApis::ListTokensByAddressRData](docs/ListTokensByAddressRData.md)
 - [CryptoApis::ListTokensByAddressRI](docs/ListTokensByAddressRI.md)
 - [CryptoApis::ListTokensForwardingAutomationsR](docs/ListTokensForwardingAutomationsR.md)
 - [CryptoApis::ListTokensForwardingAutomationsRData](docs/ListTokensForwardingAutomationsRData.md)
 - [CryptoApis::ListTokensForwardingAutomationsRI](docs/ListTokensForwardingAutomationsRI.md)
 - [CryptoApis::ListTokensForwardingAutomationsRITS](docs/ListTokensForwardingAutomationsRITS.md)
 - [CryptoApis::ListTokensForwardingAutomationsRITSBOT](docs/ListTokensForwardingAutomationsRITSBOT.md)
 - [CryptoApis::ListTokensForwardingAutomationsRITSET](docs/ListTokensForwardingAutomationsRITSET.md)
 - [CryptoApis::ListTokensTransfersByAddressR](docs/ListTokensTransfersByAddressR.md)
 - [CryptoApis::ListTokensTransfersByAddressRData](docs/ListTokensTransfersByAddressRData.md)
 - [CryptoApis::ListTokensTransfersByAddressRI](docs/ListTokensTransfersByAddressRI.md)
 - [CryptoApis::ListTokensTransfersByTransactionHashR](docs/ListTokensTransfersByTransactionHashR.md)
 - [CryptoApis::ListTokensTransfersByTransactionHashRData](docs/ListTokensTransfersByTransactionHashRData.md)
 - [CryptoApis::ListTokensTransfersByTransactionHashRI](docs/ListTokensTransfersByTransactionHashRI.md)
 - [CryptoApis::ListTransactionsByAddressR](docs/ListTransactionsByAddressR.md)
 - [CryptoApis::ListTransactionsByAddressRData](docs/ListTransactionsByAddressRData.md)
 - [CryptoApis::ListTransactionsByAddressRI](docs/ListTransactionsByAddressRI.md)
 - [CryptoApis::ListTransactionsByAddressRIBS](docs/ListTransactionsByAddressRIBS.md)
 - [CryptoApis::ListTransactionsByAddressRIBSB](docs/ListTransactionsByAddressRIBSB.md)
 - [CryptoApis::ListTransactionsByAddressRIBSBC](docs/ListTransactionsByAddressRIBSBC.md)
 - [CryptoApis::ListTransactionsByAddressRIBSBCVin](docs/ListTransactionsByAddressRIBSBCVin.md)
 - [CryptoApis::ListTransactionsByAddressRIBSBScriptPubKey](docs/ListTransactionsByAddressRIBSBScriptPubKey.md)
 - [CryptoApis::ListTransactionsByAddressRIBSBVin](docs/ListTransactionsByAddressRIBSBVin.md)
 - [CryptoApis::ListTransactionsByAddressRIBSBVout](docs/ListTransactionsByAddressRIBSBVout.md)
 - [CryptoApis::ListTransactionsByAddressRIBSD](docs/ListTransactionsByAddressRIBSD.md)
 - [CryptoApis::ListTransactionsByAddressRIBSD2](docs/ListTransactionsByAddressRIBSD2.md)
 - [CryptoApis::ListTransactionsByAddressRIBSD2ScriptPubKey](docs/ListTransactionsByAddressRIBSD2ScriptPubKey.md)
 - [CryptoApis::ListTransactionsByAddressRIBSD2ScriptSig](docs/ListTransactionsByAddressRIBSD2ScriptSig.md)
 - [CryptoApis::ListTransactionsByAddressRIBSD2Vin](docs/ListTransactionsByAddressRIBSD2Vin.md)
 - [CryptoApis::ListTransactionsByAddressRIBSD2Vout](docs/ListTransactionsByAddressRIBSD2Vout.md)
 - [CryptoApis::ListTransactionsByAddressRIBSDScriptSig](docs/ListTransactionsByAddressRIBSDScriptSig.md)
 - [CryptoApis::ListTransactionsByAddressRIBSDVin](docs/ListTransactionsByAddressRIBSDVin.md)
 - [CryptoApis::ListTransactionsByAddressRIBSE](docs/ListTransactionsByAddressRIBSE.md)
 - [CryptoApis::ListTransactionsByAddressRIBSEC](docs/ListTransactionsByAddressRIBSEC.md)
 - [CryptoApis::ListTransactionsByAddressRIBSECGasPrice](docs/ListTransactionsByAddressRIBSECGasPrice.md)
 - [CryptoApis::ListTransactionsByAddressRIBSEGasPrice](docs/ListTransactionsByAddressRIBSEGasPrice.md)
 - [CryptoApis::ListTransactionsByAddressRIBSL](docs/ListTransactionsByAddressRIBSL.md)
 - [CryptoApis::ListTransactionsByAddressRIBSLScriptSig](docs/ListTransactionsByAddressRIBSLScriptSig.md)
 - [CryptoApis::ListTransactionsByAddressRIBSLVin](docs/ListTransactionsByAddressRIBSLVin.md)
 - [CryptoApis::ListTransactionsByBlockHashR](docs/ListTransactionsByBlockHashR.md)
 - [CryptoApis::ListTransactionsByBlockHashRData](docs/ListTransactionsByBlockHashRData.md)
 - [CryptoApis::ListTransactionsByBlockHashRI](docs/ListTransactionsByBlockHashRI.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBS](docs/ListTransactionsByBlockHashRIBS.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSB](docs/ListTransactionsByBlockHashRIBSB.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSBC](docs/ListTransactionsByBlockHashRIBSBC.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSBCScriptPubKey](docs/ListTransactionsByBlockHashRIBSBCScriptPubKey.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSBCVin](docs/ListTransactionsByBlockHashRIBSBCVin.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSBCVout](docs/ListTransactionsByBlockHashRIBSBCVout.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSBVin](docs/ListTransactionsByBlockHashRIBSBVin.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSD](docs/ListTransactionsByBlockHashRIBSD.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSD2](docs/ListTransactionsByBlockHashRIBSD2.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSD2ScriptPubKey](docs/ListTransactionsByBlockHashRIBSD2ScriptPubKey.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSD2ScriptSig](docs/ListTransactionsByBlockHashRIBSD2ScriptSig.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSD2Vin](docs/ListTransactionsByBlockHashRIBSD2Vin.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSD2Vout](docs/ListTransactionsByBlockHashRIBSD2Vout.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSDScriptPubKey](docs/ListTransactionsByBlockHashRIBSDScriptPubKey.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSDVin](docs/ListTransactionsByBlockHashRIBSDVin.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSDVout](docs/ListTransactionsByBlockHashRIBSDVout.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSE](docs/ListTransactionsByBlockHashRIBSE.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSEC](docs/ListTransactionsByBlockHashRIBSEC.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSEGasPrice](docs/ListTransactionsByBlockHashRIBSEGasPrice.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSL](docs/ListTransactionsByBlockHashRIBSL.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSLScriptPubKey](docs/ListTransactionsByBlockHashRIBSLScriptPubKey.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSLVin](docs/ListTransactionsByBlockHashRIBSLVin.md)
 - [CryptoApis::ListTransactionsByBlockHashRIBSLVout](docs/ListTransactionsByBlockHashRIBSLVout.md)
 - [CryptoApis::ListTransactionsByBlockHashRIFee](docs/ListTransactionsByBlockHashRIFee.md)
 - [CryptoApis::ListTransactionsByBlockHashRIRecipients](docs/ListTransactionsByBlockHashRIRecipients.md)
 - [CryptoApis::ListTransactionsByBlockHashRISenders](docs/ListTransactionsByBlockHashRISenders.md)
 - [CryptoApis::ListTransactionsByBlockHeightR](docs/ListTransactionsByBlockHeightR.md)
 - [CryptoApis::ListTransactionsByBlockHeightRData](docs/ListTransactionsByBlockHeightRData.md)
 - [CryptoApis::ListTransactionsByBlockHeightRI](docs/ListTransactionsByBlockHeightRI.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBS](docs/ListTransactionsByBlockHeightRIBS.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSB](docs/ListTransactionsByBlockHeightRIBSB.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSBC](docs/ListTransactionsByBlockHeightRIBSBC.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSBScriptPubKey](docs/ListTransactionsByBlockHeightRIBSBScriptPubKey.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSBVout](docs/ListTransactionsByBlockHeightRIBSBVout.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSD](docs/ListTransactionsByBlockHeightRIBSD.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSD2](docs/ListTransactionsByBlockHeightRIBSD2.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSD2Vin](docs/ListTransactionsByBlockHeightRIBSD2Vin.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSDScriptPubKey](docs/ListTransactionsByBlockHeightRIBSDScriptPubKey.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSDScriptSig](docs/ListTransactionsByBlockHeightRIBSDScriptSig.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSDVin](docs/ListTransactionsByBlockHeightRIBSDVin.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSDVout](docs/ListTransactionsByBlockHeightRIBSDVout.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSE](docs/ListTransactionsByBlockHeightRIBSE.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSEC](docs/ListTransactionsByBlockHeightRIBSEC.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSECGasPrice](docs/ListTransactionsByBlockHeightRIBSECGasPrice.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSL](docs/ListTransactionsByBlockHeightRIBSL.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSLScriptPubKey](docs/ListTransactionsByBlockHeightRIBSLScriptPubKey.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSLScriptSig](docs/ListTransactionsByBlockHeightRIBSLScriptSig.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSLVin](docs/ListTransactionsByBlockHeightRIBSLVin.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIBSLVout](docs/ListTransactionsByBlockHeightRIBSLVout.md)
 - [CryptoApis::ListTransactionsByBlockHeightRIFee](docs/ListTransactionsByBlockHeightRIFee.md)
 - [CryptoApis::ListUnconfirmedOmniTransactionsByAddressR](docs/ListUnconfirmedOmniTransactionsByAddressR.md)
 - [CryptoApis::ListUnconfirmedOmniTransactionsByAddressRData](docs/ListUnconfirmedOmniTransactionsByAddressRData.md)
 - [CryptoApis::ListUnconfirmedOmniTransactionsByAddressRI](docs/ListUnconfirmedOmniTransactionsByAddressRI.md)
 - [CryptoApis::ListUnconfirmedOmniTransactionsByAddressRIFee](docs/ListUnconfirmedOmniTransactionsByAddressRIFee.md)
 - [CryptoApis::ListUnconfirmedOmniTransactionsByAddressRISenders](docs/ListUnconfirmedOmniTransactionsByAddressRISenders.md)
 - [CryptoApis::ListUnconfirmedOmniTransactionsByPropertyIDR](docs/ListUnconfirmedOmniTransactionsByPropertyIDR.md)
 - [CryptoApis::ListUnconfirmedOmniTransactionsByPropertyIDRData](docs/ListUnconfirmedOmniTransactionsByPropertyIDRData.md)
 - [CryptoApis::ListUnconfirmedOmniTransactionsByPropertyIDRI](docs/ListUnconfirmedOmniTransactionsByPropertyIDRI.md)
 - [CryptoApis::ListXRPRippleTransactionsByAddressR](docs/ListXRPRippleTransactionsByAddressR.md)
 - [CryptoApis::ListXRPRippleTransactionsByAddressRData](docs/ListXRPRippleTransactionsByAddressRData.md)
 - [CryptoApis::ListXRPRippleTransactionsByAddressRI](docs/ListXRPRippleTransactionsByAddressRI.md)
 - [CryptoApis::ListXRPRippleTransactionsByAddressRIFee](docs/ListXRPRippleTransactionsByAddressRIFee.md)
 - [CryptoApis::ListXRPRippleTransactionsByAddressRIOffer](docs/ListXRPRippleTransactionsByAddressRIOffer.md)
 - [CryptoApis::ListXRPRippleTransactionsByAddressRIReceive](docs/ListXRPRippleTransactionsByAddressRIReceive.md)
 - [CryptoApis::ListXRPRippleTransactionsByAddressRIValue](docs/ListXRPRippleTransactionsByAddressRIValue.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHashR](docs/ListXRPRippleTransactionsByBlockHashR.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHashRData](docs/ListXRPRippleTransactionsByBlockHashRData.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHashRI](docs/ListXRPRippleTransactionsByBlockHashRI.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHashRIFee](docs/ListXRPRippleTransactionsByBlockHashRIFee.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHashRIOffer](docs/ListXRPRippleTransactionsByBlockHashRIOffer.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHashRIReceive](docs/ListXRPRippleTransactionsByBlockHashRIReceive.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHashRIRecipients](docs/ListXRPRippleTransactionsByBlockHashRIRecipients.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHashRISenders](docs/ListXRPRippleTransactionsByBlockHashRISenders.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHashRIValue](docs/ListXRPRippleTransactionsByBlockHashRIValue.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHeightR](docs/ListXRPRippleTransactionsByBlockHeightR.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHeightRData](docs/ListXRPRippleTransactionsByBlockHeightRData.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHeightRI](docs/ListXRPRippleTransactionsByBlockHeightRI.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHeightRIFee](docs/ListXRPRippleTransactionsByBlockHeightRIFee.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHeightRIOffer](docs/ListXRPRippleTransactionsByBlockHeightRIOffer.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHeightRIReceive](docs/ListXRPRippleTransactionsByBlockHeightRIReceive.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHeightRIRecipients](docs/ListXRPRippleTransactionsByBlockHeightRIRecipients.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHeightRISenders](docs/ListXRPRippleTransactionsByBlockHeightRISenders.md)
 - [CryptoApis::ListXRPRippleTransactionsByBlockHeightRIValue](docs/ListXRPRippleTransactionsByBlockHeightRIValue.md)
 - [CryptoApis::ListZilliqaTransactionsByAddressR](docs/ListZilliqaTransactionsByAddressR.md)
 - [CryptoApis::ListZilliqaTransactionsByAddressRData](docs/ListZilliqaTransactionsByAddressRData.md)
 - [CryptoApis::ListZilliqaTransactionsByAddressRI](docs/ListZilliqaTransactionsByAddressRI.md)
 - [CryptoApis::ListZilliqaTransactionsByAddressRIRecipients](docs/ListZilliqaTransactionsByAddressRIRecipients.md)
 - [CryptoApis::ListZilliqaTransactionsByAddressRISenders](docs/ListZilliqaTransactionsByAddressRISenders.md)
 - [CryptoApis::ListZilliqaTransactionsByBlockHashR](docs/ListZilliqaTransactionsByBlockHashR.md)
 - [CryptoApis::ListZilliqaTransactionsByBlockHashRData](docs/ListZilliqaTransactionsByBlockHashRData.md)
 - [CryptoApis::ListZilliqaTransactionsByBlockHashRI](docs/ListZilliqaTransactionsByBlockHashRI.md)
 - [CryptoApis::ListZilliqaTransactionsByBlockHeightR](docs/ListZilliqaTransactionsByBlockHeightR.md)
 - [CryptoApis::ListZilliqaTransactionsByBlockHeightRData](docs/ListZilliqaTransactionsByBlockHeightRData.md)
 - [CryptoApis::ListZilliqaTransactionsByBlockHeightRI](docs/ListZilliqaTransactionsByBlockHeightRI.md)
 - [CryptoApis::MinedTransactionR](docs/MinedTransactionR.md)
 - [CryptoApis::MinedTransactionRB](docs/MinedTransactionRB.md)
 - [CryptoApis::MinedTransactionRBData](docs/MinedTransactionRBData.md)
 - [CryptoApis::MinedTransactionRBDataItem](docs/MinedTransactionRBDataItem.md)
 - [CryptoApis::MinedTransactionRData](docs/MinedTransactionRData.md)
 - [CryptoApis::MinedTransactionRI](docs/MinedTransactionRI.md)
 - [CryptoApis::MissingApiKey](docs/MissingApiKey.md)
 - [CryptoApis::MissingApiKeyError](docs/MissingApiKeyError.md)
 - [CryptoApis::NewBlockR](docs/NewBlockR.md)
 - [CryptoApis::NewBlockRB](docs/NewBlockRB.md)
 - [CryptoApis::NewBlockRBData](docs/NewBlockRBData.md)
 - [CryptoApis::NewBlockRBDataItem](docs/NewBlockRBDataItem.md)
 - [CryptoApis::NewBlockRData](docs/NewBlockRData.md)
 - [CryptoApis::NewBlockRI](docs/NewBlockRI.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsAndEachConfirmationR](docs/NewConfirmedCoinsTransactionsAndEachConfirmationR.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsAndEachConfirmationRB](docs/NewConfirmedCoinsTransactionsAndEachConfirmationRB.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsAndEachConfirmationRBData](docs/NewConfirmedCoinsTransactionsAndEachConfirmationRBData.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsAndEachConfirmationRBDataItem](docs/NewConfirmedCoinsTransactionsAndEachConfirmationRBDataItem.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsAndEachConfirmationRData](docs/NewConfirmedCoinsTransactionsAndEachConfirmationRData.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsAndEachConfirmationRI](docs/NewConfirmedCoinsTransactionsAndEachConfirmationRI.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsR](docs/NewConfirmedCoinsTransactionsR.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsRB](docs/NewConfirmedCoinsTransactionsRB.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsRBData](docs/NewConfirmedCoinsTransactionsRBData.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsRBDataItem](docs/NewConfirmedCoinsTransactionsRBDataItem.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsRData](docs/NewConfirmedCoinsTransactionsRData.md)
 - [CryptoApis::NewConfirmedCoinsTransactionsRI](docs/NewConfirmedCoinsTransactionsRI.md)
 - [CryptoApis::NewConfirmedInternalTransactionsAndEachConfirmationR](docs/NewConfirmedInternalTransactionsAndEachConfirmationR.md)
 - [CryptoApis::NewConfirmedInternalTransactionsAndEachConfirmationRB](docs/NewConfirmedInternalTransactionsAndEachConfirmationRB.md)
 - [CryptoApis::NewConfirmedInternalTransactionsAndEachConfirmationRBData](docs/NewConfirmedInternalTransactionsAndEachConfirmationRBData.md)
 - [CryptoApis::NewConfirmedInternalTransactionsAndEachConfirmationRBDataItem](docs/NewConfirmedInternalTransactionsAndEachConfirmationRBDataItem.md)
 - [CryptoApis::NewConfirmedInternalTransactionsAndEachConfirmationRData](docs/NewConfirmedInternalTransactionsAndEachConfirmationRData.md)
 - [CryptoApis::NewConfirmedInternalTransactionsAndEachConfirmationRI](docs/NewConfirmedInternalTransactionsAndEachConfirmationRI.md)
 - [CryptoApis::NewConfirmedInternalTransactionsR](docs/NewConfirmedInternalTransactionsR.md)
 - [CryptoApis::NewConfirmedInternalTransactionsRB](docs/NewConfirmedInternalTransactionsRB.md)
 - [CryptoApis::NewConfirmedInternalTransactionsRBData](docs/NewConfirmedInternalTransactionsRBData.md)
 - [CryptoApis::NewConfirmedInternalTransactionsRBDataItem](docs/NewConfirmedInternalTransactionsRBDataItem.md)
 - [CryptoApis::NewConfirmedInternalTransactionsRData](docs/NewConfirmedInternalTransactionsRData.md)
 - [CryptoApis::NewConfirmedInternalTransactionsRI](docs/NewConfirmedInternalTransactionsRI.md)
 - [CryptoApis::NewConfirmedTokensTransactionsAndEachConfirmationR](docs/NewConfirmedTokensTransactionsAndEachConfirmationR.md)
 - [CryptoApis::NewConfirmedTokensTransactionsAndEachConfirmationRB](docs/NewConfirmedTokensTransactionsAndEachConfirmationRB.md)
 - [CryptoApis::NewConfirmedTokensTransactionsAndEachConfirmationRBData](docs/NewConfirmedTokensTransactionsAndEachConfirmationRBData.md)
 - [CryptoApis::NewConfirmedTokensTransactionsAndEachConfirmationRBDataItem](docs/NewConfirmedTokensTransactionsAndEachConfirmationRBDataItem.md)
 - [CryptoApis::NewConfirmedTokensTransactionsAndEachConfirmationRData](docs/NewConfirmedTokensTransactionsAndEachConfirmationRData.md)
 - [CryptoApis::NewConfirmedTokensTransactionsAndEachConfirmationRI](docs/NewConfirmedTokensTransactionsAndEachConfirmationRI.md)
 - [CryptoApis::NewConfirmedTokensTransactionsR](docs/NewConfirmedTokensTransactionsR.md)
 - [CryptoApis::NewConfirmedTokensTransactionsRB](docs/NewConfirmedTokensTransactionsRB.md)
 - [CryptoApis::NewConfirmedTokensTransactionsRData](docs/NewConfirmedTokensTransactionsRData.md)
 - [CryptoApis::NewConfirmedTokensTransactionsRI](docs/NewConfirmedTokensTransactionsRI.md)
 - [CryptoApis::NewUnconfirmedCoinsTransactionsR](docs/NewUnconfirmedCoinsTransactionsR.md)
 - [CryptoApis::NewUnconfirmedCoinsTransactionsRB](docs/NewUnconfirmedCoinsTransactionsRB.md)
 - [CryptoApis::NewUnconfirmedCoinsTransactionsRBData](docs/NewUnconfirmedCoinsTransactionsRBData.md)
 - [CryptoApis::NewUnconfirmedCoinsTransactionsRBDataItem](docs/NewUnconfirmedCoinsTransactionsRBDataItem.md)
 - [CryptoApis::NewUnconfirmedCoinsTransactionsRData](docs/NewUnconfirmedCoinsTransactionsRData.md)
 - [CryptoApis::NewUnconfirmedCoinsTransactionsRI](docs/NewUnconfirmedCoinsTransactionsRI.md)
 - [CryptoApis::NewUnconfirmedTokensTransactionsR](docs/NewUnconfirmedTokensTransactionsR.md)
 - [CryptoApis::NewUnconfirmedTokensTransactionsRB](docs/NewUnconfirmedTokensTransactionsRB.md)
 - [CryptoApis::NewUnconfirmedTokensTransactionsRBData](docs/NewUnconfirmedTokensTransactionsRBData.md)
 - [CryptoApis::NewUnconfirmedTokensTransactionsRBDataItem](docs/NewUnconfirmedTokensTransactionsRBDataItem.md)
 - [CryptoApis::NewUnconfirmedTokensTransactionsRData](docs/NewUnconfirmedTokensTransactionsRData.md)
 - [CryptoApis::NewUnconfirmedTokensTransactionsRI](docs/NewUnconfirmedTokensTransactionsRI.md)
 - [CryptoApis::RequestLimitReached](docs/RequestLimitReached.md)
 - [CryptoApis::RequestLimitReachedError](docs/RequestLimitReachedError.md)
 - [CryptoApis::ResourceNotFound](docs/ResourceNotFound.md)
 - [CryptoApis::ResourceNotFoundError](docs/ResourceNotFoundError.md)
 - [CryptoApis::SyncHDWalletXPubYPubZPubR](docs/SyncHDWalletXPubYPubZPubR.md)
 - [CryptoApis::SyncHDWalletXPubYPubZPubRB](docs/SyncHDWalletXPubYPubZPubRB.md)
 - [CryptoApis::SyncHDWalletXPubYPubZPubRBData](docs/SyncHDWalletXPubYPubZPubRBData.md)
 - [CryptoApis::SyncHDWalletXPubYPubZPubRBDataItem](docs/SyncHDWalletXPubYPubZPubRBDataItem.md)
 - [CryptoApis::SyncHDWalletXPubYPubZPubRData](docs/SyncHDWalletXPubYPubZPubRData.md)
 - [CryptoApis::SyncHDWalletXPubYPubZPubRI](docs/SyncHDWalletXPubYPubZPubRI.md)
 - [CryptoApis::TokensForwardingAutomationsLimitReached](docs/TokensForwardingAutomationsLimitReached.md)
 - [CryptoApis::TokensForwardingAutomationsLimitReachedError](docs/TokensForwardingAutomationsLimitReachedError.md)
 - [CryptoApis::TokensForwardingFail](docs/TokensForwardingFail.md)
 - [CryptoApis::TokensForwardingFailData](docs/TokensForwardingFailData.md)
 - [CryptoApis::TokensForwardingFailDataItem](docs/TokensForwardingFailDataItem.md)
 - [CryptoApis::TokensForwardingSuccess](docs/TokensForwardingSuccess.md)
 - [CryptoApis::TokensForwardingSuccessData](docs/TokensForwardingSuccessData.md)
 - [CryptoApis::TokensForwardingSuccessDataItem](docs/TokensForwardingSuccessDataItem.md)
 - [CryptoApis::TokensForwardingSuccessEthereumerc20token](docs/TokensForwardingSuccessEthereumerc20token.md)
 - [CryptoApis::TokensForwardingSuccessEthereumerc721token](docs/TokensForwardingSuccessEthereumerc721token.md)
 - [CryptoApis::TokensForwardingSuccessOmnilayertoken](docs/TokensForwardingSuccessOmnilayertoken.md)
 - [CryptoApis::TokensForwardingSuccessToken](docs/TokensForwardingSuccessToken.md)
 - [CryptoApis::TransactionMined](docs/TransactionMined.md)
 - [CryptoApis::TransactionMinedData](docs/TransactionMinedData.md)
 - [CryptoApis::TransactionMinedDataItem](docs/TransactionMinedDataItem.md)
 - [CryptoApis::TransactionMinedDataItemMinedInBlock](docs/TransactionMinedDataItemMinedInBlock.md)
 - [CryptoApis::TransactionRequestApproval](docs/TransactionRequestApproval.md)
 - [CryptoApis::TransactionRequestApprovalData](docs/TransactionRequestApprovalData.md)
 - [CryptoApis::TransactionRequestApprovalDataItem](docs/TransactionRequestApprovalDataItem.md)
 - [CryptoApis::TransactionRequestBroadcasted](docs/TransactionRequestBroadcasted.md)
 - [CryptoApis::TransactionRequestBroadcastedData](docs/TransactionRequestBroadcastedData.md)
 - [CryptoApis::TransactionRequestBroadcastedDataItem](docs/TransactionRequestBroadcastedDataItem.md)
 - [CryptoApis::TransactionRequestFail](docs/TransactionRequestFail.md)
 - [CryptoApis::TransactionRequestFailData](docs/TransactionRequestFailData.md)
 - [CryptoApis::TransactionRequestFailDataItem](docs/TransactionRequestFailDataItem.md)
 - [CryptoApis::TransactionRequestMined](docs/TransactionRequestMined.md)
 - [CryptoApis::TransactionRequestMinedData](docs/TransactionRequestMinedData.md)
 - [CryptoApis::TransactionRequestRejection](docs/TransactionRequestRejection.md)
 - [CryptoApis::TransactionRequestRejectionData](docs/TransactionRequestRejectionData.md)
 - [CryptoApis::TransactionRequestRejectionDataItem](docs/TransactionRequestRejectionDataItem.md)
 - [CryptoApis::UnexpectedServerError](docs/UnexpectedServerError.md)
 - [CryptoApis::UnexpectedServerErrorError](docs/UnexpectedServerErrorError.md)
 - [CryptoApis::UnsupportedMediaType](docs/UnsupportedMediaType.md)
 - [CryptoApis::UnsupportedMediaTypeError](docs/UnsupportedMediaTypeError.md)
 - [CryptoApis::UriNotFound](docs/UriNotFound.md)
 - [CryptoApis::UriNotFoundError](docs/UriNotFoundError.md)
 - [CryptoApis::ValidateAddressR](docs/ValidateAddressR.md)
 - [CryptoApis::ValidateAddressRB](docs/ValidateAddressRB.md)
 - [CryptoApis::ValidateAddressRBData](docs/ValidateAddressRBData.md)
 - [CryptoApis::ValidateAddressRBDataItem](docs/ValidateAddressRBDataItem.md)
 - [CryptoApis::ValidateAddressRData](docs/ValidateAddressRData.md)
 - [CryptoApis::ValidateAddressRI](docs/ValidateAddressRI.md)
 - [CryptoApis::WalletAsAServiceDepositAddressesLimitReached](docs/WalletAsAServiceDepositAddressesLimitReached.md)
 - [CryptoApis::WalletAsAServiceDepositAddressesLimitReachedError](docs/WalletAsAServiceDepositAddressesLimitReachedError.md)
 - [CryptoApis::WalletAsAServiceNoDepositAddressesFound](docs/WalletAsAServiceNoDepositAddressesFound.md)
 - [CryptoApis::WalletAsAServiceNoDepositAddressesFoundError](docs/WalletAsAServiceNoDepositAddressesFoundError.md)
 - [CryptoApis::WalletAsAServiceTokenNotSupported](docs/WalletAsAServiceTokenNotSupported.md)
 - [CryptoApis::WalletAsAServiceTokenNotSupportedError](docs/WalletAsAServiceTokenNotSupportedError.md)
 - [CryptoApis::WalletAsAServiceWalletBalanceNotEnough](docs/WalletAsAServiceWalletBalanceNotEnough.md)
 - [CryptoApis::WalletAsAServiceWalletBalanceNotEnoughError](docs/WalletAsAServiceWalletBalanceNotEnoughError.md)
 - [CryptoApis::XpubNotSynced](docs/XpubNotSynced.md)
 - [CryptoApis::XpubNotSyncedError](docs/XpubNotSyncedError.md)
 - [CryptoApis::XpubSyncInProgress](docs/XpubSyncInProgress.md)
 - [CryptoApis::XpubSyncInProgressError](docs/XpubSyncInProgressError.md)


## Documentation for Authorization


### ApiKey


- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

